==> haskell-utf8-string-1.0.1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utf8-string
version: 1.0.1.1
id: utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
key: utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
license: BSD-3-Clause
maintainer: emertens@galois.com
author: Eric Mertens
homepage: http://github.com/glguy/utf8-string/
synopsis: Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.
category: Codec
abi: 03d2b6edbbe4042d502eabc2ba3840fc
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8
import-dirs: /usr/lib/ghc-8.4.3/site-local/utf8-string-1.0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/utf8-string-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/utf8-string-1.0.1.1
hs-libraries: HSutf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html: /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utf8-string-1.0.1.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utf8-string
version: 1.0.1.1
id: utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
key: utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
license: BSD-3-Clause
maintainer: emertens@galois.com
author: Eric Mertens
homepage: http://github.com/glguy/utf8-string/
synopsis: Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.
category: Codec
abi: dd3a3f7ad817044d0c842dbd961df923
exposed: True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8
import-dirs: /usr/lib/ghc-8.6.1/site-local/utf8-string-1.0.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/utf8-string-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/utf8-string-1.0.1.1
hs-libraries: HSutf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html: /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
